<?php

declare(strict_types=1);

namespace Drupal\paragraphs_blokkli\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Paragraph Builder settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'paragraphs_blokkli_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['paragraphs_blokkli.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['schema_file'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Schema File'),
      '#description' => $this->t('The schema file is generated by the frontend application.'),
      '#default_value' => $this->config('paragraphs_blokkli.settings')->get('schema_file'),
    ];
    return parent::buildForm($form, $form_state);
  }

  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    $file_path = $form_state->getValue('schema_file');
    if (!file_exists($file_path)) {
      $form_state->setErrorByName('schema_file', $this->t('The file does not exist.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('paragraphs_blokkli.settings')
      ->set('schema_file', $form_state->getValue('schema_file'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
